@@ -14,7 +14,7 @@ def get_raw_types() -> Dict[str, typing.Any]:
 
 @functools.lru_cache()
 def all_name_to_asset_id() -> Dict[str, int]:
-    path = Path(__file__).parent.joinpath("resource_names.json")
+    path = Path(__file__).parent.joinpath("dread_resource_names.json")
     with path.open() as names_file:
         return json.load(names_file)
 
@@ -33,7 +33,7 @@ def name_for_asset_id(asset_id: int) -> Optional[str]:
 
 @functools.lru_cache()
 def all_name_to_property_id() -> Dict[str, int]:
-    path = Path(__file__).parent.joinpath("property_names.json")
+    path = Path(__file__).parent.joinpath("dread_property_names.json")
     with path.open() as names_file:
         return json.load(names_file)
 
